betty.project.generate.file module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.generate.file module

File utilities for site generation.

betty.project.generate.file.create_file(path: Path) → AsyncIterator[AsyncTextIOWrapper]

  Create the file for a resource.

betty.project.generate.file.create_html_resource(path: Path) → AsyncContextManager[AsyncTextIOWrapper]

  Create the file for an HTML resource.

betty.project.generate.file.create_json_resource(path: Path) → AsyncContextManager[AsyncTextIOWrapper]

  Create the file for a JSON resource.